@@ -7,7 +7,7 @@ Database schema version control library for SQLAlchemy.
 
 __author__ = 'Chris Miles'
 __copyright__ = '(c) Chris Miles 2008. All rights reserved.'
-__id__ = '$Id: __init__.py 9 2009-05-11 14:30:18Z chris $'
+__id__ = '$Id: __init__.py 10 2009-05-14 13:03:08Z chris $'
 __url__ = '$URL: https://psychofx.com/schemabot/svn/SchemaBot/trunk/schemabot/__init__.py $'
 
 
@@ -93,8 +93,11 @@ class SchemaChange(object):
             elif isinstance(change, (SA.schema.SchemaItem, SA.schema.Sequence)):
                 self.log.info("Schema change is: %s.create()" %change)
                 change.create(bind=connection)
+            elif isinstance(change, SA.schema.DDL):
+                self.log.info("Schema change is: %s.execute()" %change)
+                change.execute(bind=connection)
             else:
-                raise SchemaBotError("Invalid schema change object '%s', expecting string or sqlalchemy schema object")
+                raise SchemaBotError("Invalid schema change object '%s', expecting string or sqlalchemy schema object" %change)
     
     def downgrade(self, connection):
         changeset = self.get_changeset(connection.engine.name)
@@ -106,12 +109,14 @@ class SchemaChange(object):
             if isinstance(change, types.StringTypes):
                 self.log.info("Schema change is: %s" %change)
                 connection.execute(SA.text(change))
-            elif isinstance(change, SA.schema.Table):
+            elif isinstance(change, (SA.schema.SchemaItem, SA.schema.Sequence)):
                 self.log.info("Schema change is: %s.drop()" %change)
                 change.drop(bind=connection)
+            elif isinstance(change, SA.schema.DDL):
+                self.log.info("Schema change is: %s.execute()" %change)
+                change.execute(bind=connection)
             else:
-                raise SchemaBotError("Invalid schema change object '%s', expecting string or sqlalchemy.schema.Table")
-    
+                raise SchemaBotError("Invalid schema change object '%s', expecting string or sqlalchemy.schema.Table" %change)
     
 
 
