@@ -359,8 +359,7 @@ class TestSchemaBot(unittest.TestCase):
         
         self.failUnlessEqual(test1_table.exists(), False)
     
-    def test_schema_update_sa_sequence(self):
-        # test1_seq = SA.Sequence("test1seq", start=100)
+    def test_schema_update_sa_sequence_upgrade(self):
         test1_seq = SA.Sequence("test1seq", self.metadata)
         schemabot = SchemaBot(self.metadata)
         schemabot.define_schema(1, upgrade=[test1_seq])
@@ -380,6 +379,55 @@ class TestSchemaBot(unittest.TestCase):
         # self.failUnlessEqual(result, 100)
         self.failUnlessEqual(result, 1L)
     
+    def test_schema_update_sa_sequence_downgrade(self):
+        test1_seq = SA.Sequence("test1seq", self.metadata)
+        schemabot = SchemaBot(self.metadata)
+        schemabot.define_schema(1, upgrade=[test1_seq], downgrade=[test1_seq])
+        schemabot.schema_update()
+        
+        result = schemabot.get_current_version()
+        self.failUnlessEqual(result, 1)
+        
+        result = self.engine.execute(test1_seq)
+        
+        # If Sequences aren't supported by engine then skip the test
+        if result is None:
+            raise nose.SkipTest
+        
+        # Downgrade
+        schemabot.schema_update(version=0)
+        self.failUnlessRaises(
+            (SA.exceptions.OperationalError, SA.exceptions.ProgrammingError),
+            self.engine.execute, test1_seq
+        )
+    
+    def test_schema_update_ddl_upgrade(self):
+        test1_ddl = SA.DDL("CREATE TABLE foo (val INTEGER)")
+        schemabot = SchemaBot(self.metadata)
+        schemabot.define_schema(1, upgrade=[test1_ddl])
+        
+        schemabot.schema_update()
+        
+        result = schemabot.get_current_version()
+        self.failUnlessEqual(result, 1)
+    
+    def test_schema_update_ddl_downgrade(self):
+        test1_ddl_create = SA.DDL("CREATE TABLE foo (val INTEGER)")
+        test1_ddl_drop = SA.DDL("DROP TABLE foo")
+        schemabot = SchemaBot(self.metadata)
+        schemabot.define_schema(1, upgrade=[test1_ddl_create], downgrade=[test1_ddl_drop])
+        
+        schemabot.schema_update()
+        
+        result = schemabot.get_current_version()
+        self.failUnlessEqual(result, 1)
+        
+        # Downgrade
+        schemabot.schema_update(version=0)
+        
+        result = schemabot.get_current_version()
+        self.failUnlessEqual(result, 0)
+    
 
 
 
